---
title: <span class="badge object-type-enum"></span> TextMode
---
# <span class="badge object-type-enum"></span> TextMode

## Definition

```python
class TextMode(enum.StrEnum):
    HTML = "html"
    MARKDOWN = "markdown"
    CODE = "code"
```
